/**
 * Copyright (c) 2004, Thomas Guest.
 * @file
 * @brief  This file implements some utilities for creating CPP files.
 */

#include "cppfileutils.hpp"
#include "stringutils.hpp"
#include <iterator>

namespace
{

/**
 * @brief Return a standardised include guard name, based on the
 * input basename of the file.
 */
std::string
includeGuardName(std::string const & basename)
{
    std::string const upper = upperCase(basename);
    return upper + "_HPP_INCLUDED";
}

} // anonymous namespace

void 
putHeader(std::ostream & os, int argc, char const * argv[])
{
    os << "// GENERATED FILE. DO NOT EDIT.\n";
    os << "// Generated by: ";

    std::copy(argv, 
              argv + argc,
              std::ostream_iterator<char const *>
                  (os, " "));
    
    os << "\n// On: " << __DATE__;
    os <<
         "\n"
         "/**\n"
         " * Copyright (c) 2004, Thomas Guest.\n"
         " * @file\n"
         " * @brief Generated section decoders.\n"
         " */\n\n";    
}


void
openIncludeGuard(std::ostream & hpp, 
                 std::string const & basename)
{
    std::string const & guard 
              = includeGuardName(basename);
    
    hpp << "#ifndef " + guard + "\n";
    hpp << "#define " + guard + "\n\n";
}


void
closeIncludeGuard(std::ostream & hpp, 
                  std::string const & basename)
{
    std::string const & guard 
              = includeGuardName(basename);
    
    hpp << "\n\n#endif // " + guard + "\n";
}


std::string
decodeFunctionName(std::string const & section_name)
{
    return std::string("decode_") + section_name;
}


void
forwardDeclareClass(std::ostream & cpp,
                    std::string const & class_name)
{
    cpp << "class " + class_name + ";\n";
}


void
includeLocalFile(std::ostream & cpp,
                 std::string const & to_include)
{
    cpp << "#include \"" + to_include + "\"\n";
}

